# PostCreateOrUpdateEmailTemplateRequestFormatReplyToEmailType

Type of the replyTo email.

## Enum

* `TENANTEMAIL` (value: `'TenantEmail'`)

* `RUNOWNER` (value: `'RunOwner'`)

* `SPECIFICEMAIL` (value: `'SpecificEmail'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


